@@ -295,6 +295,15 @@ class DebBuildConfig(object):
   commit_message_from_changelog = _bool_property('commit-message-from-changelog',
        "Whether the commit message should come from debian/changelog", default=False)
 
+  quilt_smart_merge = _bool_property('quilt-smart-merge',
+    "Automatically unapply quilt patches during merge", default=True)
+
+  quilt_tree_policy = _opt_property('quilt-tree-policy',
+      "Whether to automatically apply/unapply quilt patches after tree operations")
+
+  quilt_commit_policy = _opt_property("quilt-commit-policy",
+        "Policy for committing quilt patches (applied / unapplied)")
+
 
 def _test():
   import doctest
